@@ -13,14 +13,14 @@ our @ISA = qw(Exporter);
 
 our @EXPORT = qw(getHolidays isHoliday);
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 
 our $FurikaeStr = '振替';
 
 my @StaticHoliday = (
 # 山の日を8/11に戻す
-		     {'start' => 2021, 'end' => 2999,
+		     {'start' => 2022, 'end' => 2999,
 		      'days' => {1  => { 1 => '元日'},
 				 2  => {11 => '建国記念の日',
 					23 => '天皇誕生日'},
@@ -33,6 +33,20 @@ my @StaticHoliday = (
 					23 => '勤労感謝の日'},
 				},
 		     },
+# 2021年は山の日が8/8に移動
+		     {'start' => 2021, 'end' => 2021,
+		      'days' => {1  => { 1 => '元日'},
+				 2  => {11 => '建国記念の日',
+					23 => '天皇誕生日'},
+				 4  => {29 => '昭和の日'},
+				 5  => { 3 => '憲法記念日',
+					 4 => 'みどりの日',
+					 5 => 'こどもの日'},
+				 8  => { 8 => '山の日'},
+				 11 => { 3 => '文化の日',
+					23 => '勤労感謝の日'},
+				},
+		     },
 # 2020年は山の日が8/10に移動
 		     {'start' => 2020, 'end' => 2020,
 		      'days' => {1  => { 1 => '元日'},
@@ -356,17 +370,20 @@ sub get_holidays {
     } elsif ($year == 2020 && $mon == 7) {
 	# 2020年はオリンピックにあわせて変更となりHappy Mondayではない
 	$holidays{24} = 'スポーツの日';
-    } elsif ($year >= 2021 && $mon == 10) {
-	# 2021年以降は第二月曜に戻る
+    } elsif ($year == 2021 && $mon == 7) {
+	# 2021年もオリンピックにあわせて変更となりHappy Mondayではない
+	$holidays{23} = 'スポーツの日';
+    } elsif ($year >= 2022 && $mon == 10) {
+	# 2022年以降は第二月曜に戻る
 	$holidays{$mondays[1]} = 'スポーツの日';
     }
 
     # 海の日追加
     if ($year >= 2003 && $mon == 7) {
-	if ($year != 2020) {
+	if    ($year == 2020) {$holidays{23} = '海の日';} # 2020年は7/23に変更
+	elsif ($year == 2021) {$holidays{22} = '海の日';} # 2021年は7/22に変更
+	else {
 	    $holidays{$mondays[2]} = '海の日';
-	} else {
-	    $holidays{23} = '海の日';	# 2020年は7/23に変更される
 	}
     }
 
